@@ -1,11 +1,7 @@
-import sys
 from importlib.metadata import PackageNotFoundError, version
 
 from .calculator import Calculator
 
-if sys.version_info < (3,):
-    raise Exception('Calculator needs Python 3.')
-
 try:
     __version__ = version("rpnpy")
 except PackageNotFoundError:
@@ -16,4 +12,4 @@ except PackageNotFoundError:
 # Keep Python linters quiet.
 _ = Calculator
 
-__all__ = ['Calculator']
+__all__ = ["Calculator"]
